@@ -30,6 +30,7 @@
 #include "config.h"
 
 #include "audio/automatable.h"
+#include "audio/ext_port.h"
 #include "audio/fader.h"
 #include "audio/passthrough_processor.h"
 #include "plugins/plugin.h"
@@ -212,28 +213,55 @@ channel_fields_schema[] =
     Channel, aggregated_plugins,
     num_aggregated_plugins,
     &plugin_schema, 0, CYAML_UNLIMITED),
+  CYAML_FIELD_MAPPING (
+    "prefader", CYAML_FLAG_DEFAULT,
+    Channel, prefader,
+    passthrough_processor_fields_schema),
   CYAML_FIELD_MAPPING (
     "fader", CYAML_FLAG_DEFAULT,
     Channel, fader, fader_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
-    "stereo_in", CYAML_FLAG_POINTER,
+    "stereo_in",
+    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
     Channel, stereo_in,
     stereo_ports_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
-    "midi_in", CYAML_FLAG_POINTER,
+    "midi_in",
+    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
     Channel, midi_in,
     port_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
-    "piano_roll", CYAML_FLAG_POINTER,
+    "midi_out",
+    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
+    Channel, midi_out,
+    port_fields_schema),
+	CYAML_FIELD_MAPPING_PTR (
+    "piano_roll",
+    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
     Channel, piano_roll,
     port_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
-    "stereo_out", CYAML_FLAG_POINTER,
+    "stereo_out",
+    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
     Channel, stereo_out,
     stereo_ports_fields_schema),
 	CYAML_FIELD_INT (
     "output_pos", CYAML_FLAG_DEFAULT,
     Channel, output_pos),
+  CYAML_FIELD_SEQUENCE_COUNT (
+    "ext_midi_ins", CYAML_FLAG_DEFAULT,
+    Channel, ext_midi_ins, num_ext_midi_ins,
+    &ext_port_schema, 0, CYAML_UNLIMITED),
+  CYAML_FIELD_INT (
+    "all_midi_ins", CYAML_FLAG_DEFAULT,
+    Channel, all_midi_ins),
+  CYAML_FIELD_SEQUENCE_FIXED (
+    "midi_channels", CYAML_FLAG_DEFAULT,
+    Channel, midi_channels,
+    &int_schema, 16),
+  CYAML_FIELD_INT (
+    "all_midi_channels", CYAML_FLAG_DEFAULT,
+    Channel, all_midi_channels),
 
 	CYAML_FIELD_END
 };
@@ -268,6 +296,13 @@ channel_append_all_ports (
   int *   size,
   int     include_plugins);
 
+/**
+ * Exposes the channel's ports to the backend.
+ */
+void
+channel_expose_ports_to_backend (
+  Channel * ch);
+
 /**
  * Connects the channel's ports.
  */
