@@ -94,6 +94,15 @@ typedef enum AudioBackend
   NUM_AUDIO_BACKENDS,
 } AudioBackend;
 
+static const char * audio_backend_str[] =
+{
+  "Dummy",
+  "ALSA",
+  "JACK",
+  "PortAudio",
+  "invalid"
+};
+
 typedef enum MidiBackend
 {
   MIDI_BACKEND_DUMMY,
@@ -102,6 +111,14 @@ typedef enum MidiBackend
   NUM_MIDI_BACKENDS,
 } MidiBackend;
 
+static const char * midi_backend_str[] =
+{
+  "Dummy",
+  "ALSA",
+  "JACK",
+  "invalid"
+};
+
 typedef enum AudioEngineJackTransportType
 {
   AUDIO_ENGINE_JACK_TIMEBASE_MASTER,
@@ -134,12 +151,24 @@ typedef struct AudioEngine
 
   /** Current MIDI backend. */
   MidiBackend        midi_backend;
-	uint32_t           block_length;   ///< Audio buffer size (block length)
-	size_t             midi_buf_size;  ///< Size of MIDI port buffers
-	uint32_t           sample_rate;    ///< Sample rate
-  int               frames_per_tick;  ///< number of frames per tick
-	int               buf_size_set;   ///< True iff buffer size callback fired
-  Mixer              mixer;        ///< the mixer
+
+  /** Audio buffer size (block length). */
+	uint32_t           block_length;
+
+  /** Size of MIDI port buffers. */
+	size_t             midi_buf_size;
+
+  /** Sample rate. */
+	uint32_t           sample_rate;
+
+  /** Number of frames/samples per tick. */
+  int               frames_per_tick;
+
+  /** True iff buffer size callback fired. */
+	int               buf_size_set;
+
+  /** The mixer. */
+  Mixer              mixer;
 
   /**
    * Audio intefrace outputs (only 2 are used).
@@ -301,18 +330,10 @@ engine_fields_schema[] =
     "mixer", CYAML_FLAG_DEFAULT,
     AudioEngine, mixer,
     mixer_fields_schema),
-	//CYAML_FIELD_MAPPING_PTR (
-    //"stereo_in", CYAML_FLAG_POINTER,
-    //AudioEngine, stereo_in,
-    //stereo_ports_fields_schema),
-	//CYAML_FIELD_MAPPING_PTR (
-    //"stereo_out", CYAML_FLAG_POINTER,
-    //AudioEngine, stereo_out,
-    //stereo_ports_fields_schema),
-	//CYAML_FIELD_MAPPING_PTR (
-    //"midi_in", CYAML_FLAG_POINTER,
-    //AudioEngine, midi_in,
-    //port_fields_schema),
+  CYAML_FIELD_MAPPING_PTR (
+    "monitor_out", CYAML_FLAG_POINTER,
+    AudioEngine, monitor_out,
+    stereo_ports_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
     "midi_editor_manual_press", CYAML_FLAG_POINTER,
     AudioEngine, midi_editor_manual_press,
@@ -321,6 +342,10 @@ engine_fields_schema[] =
     "transport", CYAML_FLAG_DEFAULT,
     AudioEngine, transport,
     transport_fields_schema),
+  CYAML_FIELD_MAPPING (
+    "control_room", CYAML_FLAG_DEFAULT,
+    AudioEngine, control_room,
+    control_room_fields_schema),
 
 	CYAML_FIELD_END
 };
@@ -347,6 +372,14 @@ void
 engine_init (AudioEngine * self,
              int           loading);
 
+/**
+ * Activates the audio engine to start receiving
+ * events.
+ */
+void
+engine_activate (
+  AudioEngine * self);
+
 /**
  * Updates frames per tick based on the time sig, the BPM,
  * and the sample rate
@@ -391,6 +424,35 @@ engine_post_process ();
 void
 engine_fill_out_bufs ();
 
+/**
+ * Returns 1 if the port is an engine port or
+ * control room port, otherwise 0.
+ */
+int
+engine_is_port_own (
+  AudioEngine * self,
+  const Port *  port);
+
+/**
+ * Returns the audio backend as a string.
+ */
+static inline const char *
+engine_audio_backend_to_string (
+  AudioBackend backend)
+{
+  return audio_backend_str[backend];
+}
+
+/**
+ * Returns the MIDI backend as a string.
+ */
+static inline const char *
+engine_midi_backend_to_string (
+  MidiBackend backend)
+{
+  return midi_backend_str[backend];
+}
+
 /**
  * Closes any connections and free's data.
  */
