@@ -29,6 +29,9 @@
 #include "audio/region.h"
 #include "utils/yaml.h"
 
+typedef struct _TrackLaneWidget TrackLaneWidget;
+typedef void MIDI_FILE;
+
 /**
  * @addtogroup audio
  *
@@ -36,8 +39,6 @@
  */
 #define MAX_REGIONS 300
 
-typedef struct _TrackLaneWidget TrackLaneWidget;
-
 /**
  * A TrackLane belongs to a Track (can have many
  * TrackLanes in a Track) and contains Regions.
@@ -166,6 +167,14 @@ TrackLane *
 track_lane_clone (
   TrackLane * lane);
 
+/**
+ * Writes the lane to the given MIDI file.
+ */
+void
+track_lane_write_to_midi_file (
+  const TrackLane * self,
+  MIDI_FILE *       mf);
+
 /**
  * Frees the TrackLane.
  */
