@@ -228,70 +228,56 @@ static const cyaml_schema_value_t
 };
 
 void
-lv2_plugin_init_loaded (Lv2Plugin * lv2_plgn);
+lv2_plugin_init_loaded (
+  Lv2Plugin * lv2_plgn);
 
 char*
-lv2_make_path(LV2_State_Make_Path_Handle handle,
-               const char*                path);
+lv2_make_path (
+  LV2_State_Make_Path_Handle handle,
+  const char*                path);
 
 void
-lv2_save(Lv2Plugin* plugin, const char* dir);
+lv2_save (
+  Lv2Plugin* plugin,
+  const char* dir);
 
-typedef int (*PresetSink)(Lv2Plugin*           plugin,
-                          const LilvNode* node,
-                          const LilvNode* title,
-                          void*           data);
+typedef int (*PresetSink)
+  (Lv2Plugin*           plugin,
+  const LilvNode* node,
+  const LilvNode* title,
+  void*           data);
 
 int
-lv2_load_presets(Lv2Plugin* plugin, PresetSink sink, void* data);
+lv2_load_presets (
+  Lv2Plugin* plugin,
+  PresetSink sink,
+  void* data);
 
 int
-lv2_unload_presets(Lv2Plugin* plugin);
+lv2_unload_presets (
+  Lv2Plugin* plugin);
 
 void
-lv2_apply_state(Lv2Plugin* plugin, LilvState* state);
+lv2_apply_state (
+  Lv2Plugin* plugin,
+  LilvState* state);
 
 int
-lv2_apply_preset(Lv2Plugin* plugin, const LilvNode* preset);
+lv2_apply_preset (
+  Lv2Plugin* plugin,
+  const LilvNode* preset);
 
 int
-lv2_save_preset(Lv2Plugin*       plugin,
-                 const char* dir,
-                 const char* uri,
-                 const char* label,
-                 const char* filename);
+lv2_save_preset (
+  Lv2Plugin *  plugin,
+  const char * dir,
+  const char * uri,
+  const char * label,
+  const char * filename);
 
 int
-lv2_delete_current_preset(Lv2Plugin* plugin);
-
-static inline char*
-lv2_strdup(const char* str)
-{
-	const size_t len  = strlen(str);
-	char*        copy = (char*)malloc(len + 1);
-	memcpy(copy, str, len + 1);
-	return copy;
-}
-
-/**
- * Joins two strings.
- *
- * Used in the state when creating paths. Can
- * probably get rid of this and use glib.
- */
-static inline char*
-lv2_strjoin(const char* a, const char* b)
-{
-	const size_t a_len = strlen(a);
-	const size_t b_len = strlen(b);
-	char* const  out   = (char*)malloc(a_len + b_len + 1);
-
-	memcpy(out,         a, a_len);
-	memcpy(out + a_len, b, b_len);
-	out[a_len + b_len] = '\0';
-
-	return out;
-}
+lv2_delete_current_preset (
+  Lv2Plugin* plugin);
 
 /**
  * Returns the Lv2Port corresponding to the given
