@@ -69,7 +69,9 @@
                    cyaml_strerror (err)); \
       } \
  \
-    char * new_str = g_strdup (output); \
+    char * new_str = \
+      calloc (output_len + 1, sizeof (char));\
+    memcpy (new_str, output, output_len);\
     new_str[output_len] = '\0'; \
     config.mem_fn(config.mem_ctx, output, 0); \
  \
@@ -118,7 +120,7 @@
   }
 
 static const cyaml_config_t config = {
-	.log_level = CYAML_LOG_DEBUG, /* Logging errors and warnings only. */
+	.log_level = CYAML_LOG_WARNING, /* Logging errors and warnings only. */
 	.log_fn = cyaml_log,            /* Use the default logging function. */
 	.mem_fn = cyaml_mem,            /* Use the default memory allocator. */
 };
