@@ -236,7 +236,7 @@ activate_about (GSimpleAction *action,
       "Olivier Humbert <trebmuh@tuxfamily.org>\n"
       "Waui\n"
       "Allan Nordhøy <epost@anotheragency.no>\n"
-      "WaldiS\n"
+      "WaldiS <admin@sto.ugu.pl>\n"
       "Silvério Santos\n"
       "Swann Martinet";
 
@@ -494,7 +494,7 @@ run_open_dialog (GtkDialog * dialog)
       char * filename =
         gtk_file_chooser_get_filename (chooser);
       g_message ("filename %s", filename);
-      res = project_load (filename);
+      res = project_load (filename, 0);
       g_free (filename);
     }
 
@@ -516,7 +516,7 @@ activate_open (GSimpleAction *action,
       char *filename =
         gtk_file_chooser_get_filename (
           GTK_FILE_CHOOSER (dialog));
-      project_load (filename);
+      project_load (filename, 0);
     }
 
   gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -537,9 +537,7 @@ activate_save (GSimpleAction *action,
      }
    g_message ("%s project dir", PROJECT->dir);
 
-   char * dir = g_strdup (PROJECT->dir);
-   project_save (PROJECT, dir);
-   g_free (dir);
+   project_save (PROJECT, PROJECT->dir, 0);
 }
 
 void
@@ -568,9 +566,13 @@ activate_save_as (GSimpleAction *action,
   gtk_file_chooser_set_do_overwrite_confirmation (
     chooser, TRUE);
 
+  char * project_file_path =
+    project_get_project_file_path (
+      PROJECT, 0);
   char * str =
     io_path_get_parent_dir (
-      PROJECT->project_file_path);
+      project_file_path);
+  g_free (project_file_path);
   gtk_file_chooser_select_filename (
     chooser,
     str);
@@ -585,7 +587,7 @@ activate_save_as (GSimpleAction *action,
 
       filename =
         gtk_file_chooser_get_filename (chooser);
-      project_save (PROJECT, filename);
+      project_save (PROJECT, filename, 0);
       g_free (filename);
     }
 
@@ -605,24 +607,13 @@ activate_export_as (GSimpleAction *action,
                   GVariant      *variant,
                   gpointer       user_data)
 {
-  /* if project is loaded */
-  if (PROJECT->project_file_path)
-    {
-      ExportDialogWidget * export =
-        export_dialog_widget_new ();
-      gtk_window_set_transient_for (
-        GTK_WINDOW (export),
-        GTK_WINDOW (MAIN_WINDOW));
-      gtk_dialog_run (GTK_DIALOG (export));
-      gtk_widget_destroy (GTK_WIDGET (export));
-    }
-  else
-    {
-      ui_show_error_message (
-        MAIN_WINDOW,
-        _("Project doesn't have a path yet. Please "
-          "save the project before exporting."));
-    }
+  ExportDialogWidget * export =
+    export_dialog_widget_new ();
+  gtk_window_set_transient_for (
+    GTK_WINDOW (export),
+    GTK_WINDOW (MAIN_WINDOW));
+  gtk_dialog_run (GTK_DIALOG (export));
+  gtk_widget_destroy (GTK_WIDGET (export));
 }
 
 void
