@@ -55,6 +55,10 @@ int
 duplicate_midi_arranger_selections_action_do (
   DuplicateMidiArrangerSelectionsAction * self)
 {
+  /* clear selections */
+  midi_arranger_selections_clear (
+    MA_SELECTIONS);
+
   MidiNote * mn;
 	for (int i = 0; i < self->mas->num_midi_notes; i++)
     {
@@ -64,7 +68,6 @@ duplicate_midi_arranger_selections_action_do (
           self->mas->midi_notes[i],
           MIDI_NOTE_CLONE_COPY_MAIN);
 
-      /* add and shift it */
       midi_region_add_midi_note (
         mn->region, mn);
       midi_note_shift_by_ticks (
@@ -73,8 +76,8 @@ duplicate_midi_arranger_selections_action_do (
         mn, self->delta, AO_UPDATE_ALL);
 
       /* select it */
-      midi_note_widget_select (
-        mn->widget, F_SELECT);
+      midi_note_select (
+        mn, F_SELECT);
     }
 
   EVENTS_PUSH (ET_MA_SELECTIONS_CHANGED,
@@ -98,9 +101,9 @@ duplicate_midi_arranger_selections_action_undo (
 
       /* shift it */
       midi_note_shift_by_ticks (
-        orig_mn, self->ticks, AO_UPDATE_ALL);
+        orig_mn, self->ticks, AO_UPDATE_THIS);
       midi_note_shift_pitch (
-        orig_mn, self->delta, AO_UPDATE_ALL);
+        orig_mn, self->delta, AO_UPDATE_THIS);
 
       /* find the actual MidiNote at the new pos */
       mn = midi_note_find (orig_mn);
