@@ -1153,24 +1153,56 @@ channel_init_loaded (Channel * ch)
   ch->prefader.channel = ch;
   ch->fader.channel = ch;
 
+  passthrough_processor_init_loaded (
+    &ch->prefader);
+  fader_init_loaded (&ch->fader);
+
+  PortType in_type =
+    ch->track->in_signal_type;
+  PortType out_type =
+    ch->track->out_signal_type;
+
   /* midi in / piano roll ports */
-  ch->piano_roll->identifier.flags =
-    PORT_FLAG_PIANO_ROLL;
-  ch->piano_roll->identifier.owner_type =
-    PORT_OWNER_TYPE_TRACK;
-  ch->midi_in->midi_events =
-    midi_events_new (
-      ch->midi_in);
-  ch->midi_out->midi_events =
-    midi_events_new (
-      ch->midi_out);
-  ch->piano_roll->midi_events =
-    midi_events_new (
-      ch->piano_roll);
-  ch->midi_in->identifier.owner_type =
-    PORT_OWNER_TYPE_TRACK;
-  ch->midi_out->identifier.owner_type =
-    PORT_OWNER_TYPE_TRACK;
+  if (track_has_piano_roll (ch->track))
+    {
+      ch->piano_roll->identifier.flags =
+        PORT_FLAG_PIANO_ROLL;
+      ch->piano_roll->identifier.owner_type =
+        PORT_OWNER_TYPE_TRACK;
+      ch->piano_roll->midi_events =
+        midi_events_new (
+          ch->piano_roll);
+    }
+
+  switch (in_type)
+    {
+    case TYPE_EVENT:
+      ch->midi_in->midi_events =
+        midi_events_new (
+          ch->midi_in);
+      ch->midi_in->identifier.owner_type =
+        PORT_OWNER_TYPE_TRACK;
+      break;
+    case TYPE_AUDIO:
+      break;
+    default:
+      break;
+    }
+
+  switch (out_type)
+    {
+    case TYPE_EVENT:
+      ch->midi_out->midi_events =
+        midi_events_new (
+          ch->midi_out);
+      ch->midi_out->identifier.owner_type =
+        PORT_OWNER_TYPE_TRACK;
+      break;
+    case TYPE_AUDIO:
+      break;
+    default:
+      break;
+    }
 
   /* routing */
   if (ch->output_pos > -1)
@@ -1205,6 +1237,44 @@ channel_init_loaded (Channel * ch)
     }
 }
 
+/**
+ * Exposes the channel's ports to the backend.
+ */
+void
+channel_expose_ports_to_backend (
+  Channel * ch)
+{
+  /* expose ports to backend */
+  if (ch->track->in_signal_type ==
+        TYPE_AUDIO)
+    {
+      port_set_expose_to_backend (
+        ch->stereo_in->l , 1);
+      port_set_expose_to_backend (
+        ch->stereo_in->r , 1);
+    }
+  if (ch->track->in_signal_type ==
+        TYPE_EVENT)
+    {
+      port_set_expose_to_backend (
+        ch->midi_in , 1);
+    }
+  if (ch->track->out_signal_type ==
+        TYPE_AUDIO)
+    {
+      port_set_expose_to_backend (
+        ch->stereo_out->l , 1);
+      port_set_expose_to_backend (
+        ch->stereo_out->r , 1);
+    }
+  if (ch->track->out_signal_type ==
+        TYPE_EVENT)
+    {
+      port_set_expose_to_backend (
+        ch->midi_out , 1);
+    }
+}
+
 /**
  * Called when the input has changed for Midi,
  * Instrument or Audio tracks.
@@ -1215,6 +1285,7 @@ channel_reconnect_ext_input_ports (
 {
   char * pname;
   int i = 0;
+  int ret;
   if (ch->track->type == TRACK_TYPE_INSTRUMENT ||
       ch->track->type == TRACK_TYPE_MIDI)
     {
@@ -1230,12 +1301,14 @@ channel_reconnect_ext_input_ports (
           while ((pname = (char *) prev_ports[i]) !=
                     NULL)
             {
-              jack_disconnect (
-                AUDIO_ENGINE->client,
-                pname,
-                jack_port_name (
-                  (jack_port_t *)
-                  ch->midi_in->data));
+              ret =
+                jack_disconnect (
+                  AUDIO_ENGINE->client,
+                  pname,
+                  jack_port_name (
+                    (jack_port_t *)
+                    ch->midi_in->data));
+              g_warn_if_fail (!ret);
               i++;
             }
         }
@@ -1255,12 +1328,14 @@ channel_reconnect_ext_input_ports (
           while ((pname = (char *) ports[i]) !=
                     NULL)
             {
-              jack_connect (
-                AUDIO_ENGINE->client,
-                pname,
-                jack_port_name (
-                  (jack_port_t *)
-                  ch->midi_in->data));
+              ret =
+                jack_connect (
+                  AUDIO_ENGINE->client,
+                  pname,
+                  jack_port_name (
+                    (jack_port_t *)
+                    ch->midi_in->data));
+              g_warn_if_fail (!ret);
               i++;
             }
         }
@@ -1270,12 +1345,14 @@ channel_reconnect_ext_input_ports (
           for (i = 0; i < ch->num_ext_midi_ins;
                i++)
             {
-              jack_connect (
-                AUDIO_ENGINE->client,
-                ch->ext_midi_ins[i]->full_name,
-                jack_port_name (
-                  (jack_port_t *)
-                  ch->midi_in->data));
+              ret =
+                jack_connect (
+                  AUDIO_ENGINE->client,
+                  ch->ext_midi_ins[i]->full_name,
+                  jack_port_name (
+                    (jack_port_t *)
+                    ch->midi_in->data));
+              g_warn_if_fail (!ret);
             }
         }
     }
@@ -1463,34 +1540,7 @@ channel_connect (
     }
 
   /* expose ports to backend */
-  if (ch->track->in_signal_type ==
-        TYPE_AUDIO)
-    {
-      port_set_expose_to_backend (
-        ch->stereo_in->l , 1);
-      port_set_expose_to_backend (
-        ch->stereo_in->r , 1);
-    }
-  if (ch->track->in_signal_type ==
-        TYPE_EVENT)
-    {
-      port_set_expose_to_backend (
-        ch->midi_in , 1);
-    }
-  if (ch->track->out_signal_type ==
-        TYPE_AUDIO)
-    {
-      port_set_expose_to_backend (
-        ch->stereo_out->l , 1);
-      port_set_expose_to_backend (
-        ch->stereo_out->r , 1);
-    }
-  if (ch->track->out_signal_type ==
-        TYPE_EVENT)
-    {
-      port_set_expose_to_backend (
-        ch->midi_out , 1);
-    }
+  channel_expose_ports_to_backend (ch);
 
   /* connect the designated midi inputs */
   channel_reconnect_ext_input_ports (ch);
@@ -1548,10 +1598,11 @@ channel_append_all_ports (
 {
   int j, k;
   Track * tr = ch->track;
+  g_warn_if_fail (tr);
   PortType in_type =
-    ch->track->in_signal_type;
+    tr->in_signal_type;
   PortType out_type =
-    ch->track->out_signal_type;
+    tr->out_signal_type;
 
 #define _ADD(port) \
   array_append ( \
@@ -1576,7 +1627,7 @@ channel_append_all_ports (
   else if (in_type == TYPE_EVENT)
     {
       _ADD (ch->midi_in);
-      if (track_has_piano_roll (ch->track))
+      if (track_has_piano_roll (tr))
         {
           _ADD (ch->piano_roll);
         }
@@ -2401,37 +2452,15 @@ channel_disconnect (
         }
     }
 
-  Track * track = channel->track;
-  switch (track->in_signal_type)
+  Port * ports[80000];
+  int    num_ports = 0;
+  channel_append_all_ports (
+    channel,
+    ports, &num_ports, 0);
+  for (int i = 0; i < num_ports; i++)
     {
-    case TYPE_AUDIO:
-      port_disconnect_all (channel->stereo_in->l);
-      port_disconnect_all (channel->stereo_in->r);
-      break;
-    case TYPE_EVENT:
-      port_disconnect_all (channel->midi_in);
-      if (track_has_piano_roll (track))
-        port_disconnect_all (channel->piano_roll);
-      break;
-    default:
-      break;
+      port_disconnect_all (ports[i]);
     }
-  switch (track->out_signal_type)
-    {
-    case TYPE_AUDIO:
-      port_disconnect_all (channel->stereo_out->l);
-      port_disconnect_all (channel->stereo_out->r);
-      break;
-    case TYPE_EVENT:
-      port_disconnect_all (channel->midi_out);
-      break;
-    default:
-      break;
-    }
-
-  passthrough_processor_disconnect_all (
-    &channel->prefader);
-  fader_disconnect_all (&channel->fader);
 
   if (recalc_graph)
     mixer_recalc_graph (MIXER);
