@@ -286,18 +286,8 @@ node_process (
 
   if (node->type == ROUTE_NODE_TYPE_PLUGIN)
     {
-      /*g_message ("processing plugin %s",*/
-                 /*node->pl->descr->name);*/
       plugin_process (
         node->pl, g_start_frames, nframes);
-      /*g_message (*/
-        /*"processing: %s at %ld "*/
-        /*"(route latency %ld)",*/
-        /*node->type == ROUTE_NODE_TYPE_PLUGIN ?*/
-          /*node->pl->descr->name :*/
-          /*node->port->identifier.label,*/
-        /*g_start_frames,*/
-        /*node->route_playback_latency);*/
     }
   else if (node->type == ROUTE_NODE_TYPE_FADER)
     {
@@ -326,8 +316,6 @@ node_process (
     {
       /* decide what to do based on what port it is */
       Port * port = node->port;
-      /*g_message ("processing port %s",*/
-                 /*node->port->label);*/
 
       /* if piano roll */
       if (port->identifier.flags &
@@ -454,6 +442,14 @@ node_process (
             }
         }
 
+      /* if exporting and the port is not a
+       * project port, ignore it */
+      else if (
+        engine_is_port_own (AUDIO_ENGINE, port) &&
+        AUDIO_ENGINE->exporting)
+        {
+        }
+
       else
         {
           port_sum_signal_from_inputs (
