@@ -188,6 +188,10 @@ tracklist_insert_track (
 
   track_set_pos (track, pos);
 
+  /* make the track the only selected track */
+  tracklist_selections_select_single (
+    TRACKLIST_SELECTIONS, track);
+
   /* move other tracks */
   for (int i = track->pos + 1;
        i < self->num_tracks; i++)
@@ -349,6 +353,7 @@ tracklist_remove_track (
 {
   g_message ("removing %s",
              track->name);
+
   int idx =
     array_index_of (
       self->tracks,
@@ -364,10 +369,12 @@ tracklist_remove_track (
   tracklist_selections_remove_track (
     TRACKLIST_SELECTIONS, track);
 
+  track_set_pos (track, -1);
+
   /* move all other tracks */
   for (int i = track->pos;
        i < self->num_tracks; i++)
-    self->tracks[i]->pos = i;
+    track_set_pos (track, i);
 
   if (track->channel)
     {
