@@ -31,6 +31,7 @@
 #include "gui/backend/piano_roll.h"
 #include "audio/track.h"
 #include "project.h"
+#include "utils/arrays.h"
 
 DRUM_LABELS;
 
@@ -61,12 +62,12 @@ init_descriptors (
         g_strdup_printf (
           "%s%d",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
       descr->note_name_pango =
         g_strdup_printf (
           "%s<sup>%d</sup>",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
       idx++;
     }
 
@@ -87,12 +88,12 @@ init_descriptors (
         g_strdup_printf (
           "%s%d",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
       descr->note_name_pango =
         g_strdup_printf (
           "%s<sup>%d</sup>",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
       idx++;
     }
   for (int i = 0; i < 128; i++)
@@ -110,24 +111,74 @@ init_descriptors (
         g_strdup_printf (
           "%s%d",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
 
       descr->note_name =
         g_strdup_printf (
           "%s%d",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
       descr->note_name_pango =
         g_strdup_printf (
           "%s<sup>%d</sup>",
           chord_descriptor_note_to_string (i % 12),
-          i / 12 - 2);
+          i / 12 - 1);
       idx++;
     }
 
   g_warn_if_fail (idx == 128);
 }
 
+/**
+ * Adds the note if it doesn't exist in the array.
+ */
+void
+piano_roll_add_current_note (
+  PianoRoll * self,
+  MidiNoteDescriptor * descr)
+{
+  if (!array_contains_int (self->current_notes,
+                       self->num_current_notes,
+                       descr->value))
+    {
+      array_append (self->current_notes,
+                    self->num_current_notes,
+                    descr->value);
+    }
+}
+
+/**
+ * Removes the note if it exists in the array.
+ */
+void
+piano_roll_remove_current_note (
+  PianoRoll * self,
+  MidiNoteDescriptor * descr)
+{
+  if (array_contains_int (self->current_notes,
+                      self->num_current_notes,
+                      descr->value))
+    {
+      array_delete (self->current_notes,
+                    self->num_current_notes,
+                    descr->value);
+    }
+}
+
+/**
+ * Returns 1 if it contains the given note, 0
+ * otherwise.
+ */
+int
+piano_roll_contains_current_note (
+  PianoRoll * self,
+  MidiNoteDescriptor * descr)
+{
+  return array_contains_int (self->current_notes,
+                         self->num_current_notes,
+                         descr->value);
+}
+
 /**
  * Inits the PianoRoll after a Project has been
  * loaded.
