@@ -134,9 +134,11 @@ draw_cb (
                          1);
   cairo_set_line_width (cr, 3.0);
   cairo_move_to (cr, x, y + (height - value_px));
-  cairo_line_to (cr, x+ width, y + (height - value_px));
+  cairo_line_to (
+    cr, x+ width, y + (height - value_px));
   cairo_stroke (cr);
-	return 0;
+
+	return FALSE;
 }
 
 
@@ -151,8 +153,6 @@ on_motion (GtkWidget * widget, GdkEvent *event)
       gtk_widget_set_state_flags (
         GTK_WIDGET (self),
         GTK_STATE_FLAG_PRELIGHT, 0);
-      bot_bar_change_status (
-        _("Fader - Click and drag to change value"));
     }
   else if (gdk_event_get_event_type (event) ==
              GDK_LEAVE_NOTIFY)
@@ -160,7 +160,6 @@ on_motion (GtkWidget * widget, GdkEvent *event)
       gtk_widget_unset_state_flags (
         GTK_WIDGET (self),
         GTK_STATE_FLAG_PRELIGHT);
-      bot_bar_change_status ("");
     }
 
   return FALSE;
