@@ -83,7 +83,7 @@ on_row_activated (GtkTreeView       *tree_view,
   if (plugin_descriptor_is_instrument (descr))
     tt = TRACK_TYPE_INSTRUMENT;
   else
-    tt = TRACK_TYPE_BUS;
+    tt = TRACK_TYPE_AUDIO_BUS;
 
   UndoableAction * ua =
     create_tracks_action_new (
