@@ -19,6 +19,7 @@
 
 #include "zrythm.h"
 #include "gui/widgets/project_assistant.h"
+#include "project.h"
 #include "utils/arrays.h"
 #include "utils/io.h"
 #include "utils/resources.h"
@@ -52,16 +53,17 @@ on_projects_selection_changed (
     {
       GtkTreePath * tp =
         (GtkTreePath *)g_list_first (selected_rows)->data;
-      gtk_tree_model_get_iter (self->model,
+      gtk_tree_model_get_iter (self->project_model,
                                &iter,
                                tp);
       GValue value = G_VALUE_INIT;
-      gtk_tree_model_get_value (self->model,
+      gtk_tree_model_get_value (self->project_model,
                                 &iter,
                                 COLUMN_PROJECT_INFO,
                                 &value);
-      self->selection = g_value_get_pointer (&value);
-      if (self->selection)
+      self->project_selection =
+        g_value_get_pointer (&value);
+      if (self->project_selection)
         {
           gtk_assistant_set_page_complete (
             GTK_ASSISTANT (self),
@@ -80,33 +82,70 @@ on_projects_selection_changed (
     }
 }
 
-void
-on_create_new_project_toggled (
-  GtkToggleButton *togglebutton,
+static void
+on_templates_selection_changed (
+  GtkTreeSelection *     ts,
   ProjectAssistantWidget * self)
 {
-  if (gtk_toggle_button_get_active (togglebutton))
+  GtkTreeIter iter;
+
+  GList * selected_rows =
+    gtk_tree_selection_get_selected_rows (
+      self->templates_selection,
+      NULL);
+  if (selected_rows)
+    {
+      GtkTreePath * tp =
+        (GtkTreePath *)g_list_first (selected_rows)->data;
+      gtk_tree_model_get_iter (self->template_model,
+                               &iter,
+                               tp);
+      GValue value = G_VALUE_INIT;
+      gtk_tree_model_get_value (self->template_model,
+                                &iter,
+                                COLUMN_PROJECT_INFO,
+                                &value);
+      self->template_selection =
+        g_value_get_pointer (&value);
+      gtk_assistant_set_page_complete (
+        GTK_ASSISTANT (self),
+        gtk_assistant_get_nth_page (
+          GTK_ASSISTANT (self), 0),
+        1);
+
+      g_list_free_full (
+        selected_rows,
+        (GDestroyNotify) gtk_tree_path_free);
+    }
+}
+
+
+void
+on_create_new_project_toggled (
+  GtkToggleButton *togglebutton,
+  ProjectAssistantWidget * self)
+{
+  int active =
+    gtk_toggle_button_get_active (togglebutton);
+
+  gtk_widget_set_visible (
+    GTK_WIDGET (self->templates_box), active);
+  gtk_widget_set_sensitive (
+    GTK_WIDGET (self->projects), !active);
+  gtk_widget_set_sensitive (
+    GTK_WIDGET (self->remove_btn), !active);
+  self->load_template = active;
+
+  if (active)
     {
-      /*gtk_tree_selection_unselect_all (self->projects_selection);*/
-      gtk_widget_set_sensitive (
-        GTK_WIDGET (self->projects), 0);
       gtk_assistant_set_page_complete (
         GTK_ASSISTANT (self),
         gtk_assistant_get_nth_page (
           GTK_ASSISTANT (self), 0),
         1);
-      /*gtk_assistant_set_page_complete (*/
-        /*GTK_ASSISTANT (self),*/
-        /*gtk_assistant_get_nth_page (*/
-          /*GTK_ASSISTANT (self), 1),*/
-        /*1);*/
-        self->selection = NULL;
     }
   else
     {
-      gtk_widget_set_sensitive (
-        GTK_WIDGET (self->projects), 1);
-
       if (gtk_tree_selection_count_selected_rows (
             self->projects_selection) <= 0)
         {
@@ -119,9 +158,9 @@ on_create_new_project_toggled (
     }
 }
 
-
 static GtkTreeModel *
-create_model (ProjectAssistantWidget * self)
+create_project_model (
+  ProjectAssistantWidget * self)
 {
   gint i = 0;
   GtkListStore *store;
@@ -152,6 +191,39 @@ create_model (ProjectAssistantWidget * self)
   return GTK_TREE_MODEL (store);
 }
 
+static GtkTreeModel *
+create_template_model (
+  ProjectAssistantWidget * self)
+{
+  gint i = 0;
+  GtkListStore *store;
+  GtkTreeIter iter;
+
+  /* create list store */
+  store = gtk_list_store_new (NUM_COLUMNS,
+                              G_TYPE_STRING,
+                              G_TYPE_STRING,
+                              G_TYPE_STRING,
+                              G_TYPE_POINTER);
+
+  /* add data to the list store */
+  ProjectInfo * nfo;
+  for (i = 0; i < self->num_template_infos; i++)
+    {
+      nfo = &self->template_infos[i];
+      gtk_list_store_append (store, &iter);
+      gtk_list_store_set (
+        store, &iter,
+        COLUMN_NAME, nfo->name,
+        COLUMN_FILENAME, nfo->filename,
+        COLUMN_MODIFIED, nfo->modified,
+        COLUMN_PROJECT_INFO, nfo,
+        -1);
+    }
+
+  return GTK_TREE_MODEL (store);
+}
+
 static void
 add_columns (GtkTreeView *treeview)
 {
@@ -195,10 +267,34 @@ refresh_projects (
   ProjectAssistantWidget *self)
 {
   /* set model to tree view */
-  self->model = create_model (self);
+  self->project_model =
+    create_project_model (self);
   gtk_tree_view_set_model (
     GTK_TREE_VIEW (self->projects),
-    self->model);
+    self->project_model);
+}
+
+static void
+refresh_templates (
+  ProjectAssistantWidget *self)
+{
+  /* set model to tree view */
+  self->template_model =
+    create_template_model (self);
+  gtk_tree_view_set_model (
+    GTK_TREE_VIEW (self->templates),
+    self->template_model);
+
+  /* select blank project */
+  GtkTreeSelection *selection =
+    gtk_tree_view_get_selection (
+      GTK_TREE_VIEW (self->templates));
+  GtkTreeIter iter;
+  gtk_tree_model_get_iter_first (
+    self->template_model,
+    &iter);
+  gtk_tree_selection_select_iter (
+    selection, &iter);
 }
 
 static void
@@ -206,18 +302,18 @@ on_project_remove_clicked (
   GtkButton * btn,
   ProjectAssistantWidget * self)
 {
-  if (self->selection)
+  if (self->project_selection)
     {
       /* remove from gsettings */
       zrythm_remove_recent_project (
-        self->selection->filename);
+        self->project_selection->filename);
 
       /* remove from treeview */
       for (int ii = 0;
            ii < self->num_project_infos; ii++)
         {
           if (&self->project_infos[ii] ==
-                self->selection)
+                self->project_selection)
             {
               --self->num_project_infos;
               for (int jj = ii;
@@ -231,7 +327,6 @@ on_project_remove_clicked (
             }
         }
 
-
         /* refresh treeview */
         refresh_projects (self);
     }
@@ -239,8 +334,9 @@ on_project_remove_clicked (
 
 
 ProjectAssistantWidget *
-project_assistant_widget_new (GtkWindow * parent,
-                            int show_create_new_project)
+project_assistant_widget_new (
+  GtkWindow * parent,
+  int         show_create_new_project)
 {
   ProjectAssistantWidget * self =
     g_object_new (
@@ -275,14 +371,65 @@ project_assistant_widget_new (GtkWindow * parent,
       g_free (dir);
     }
 
+  self->template_infos[0].name =
+    g_strdup_printf (
+      "%s", _("Blank project"));
+  self->template_infos[0].filename =
+    g_strdup ("-");
+  self->template_infos[0].modified =
+    g_strdup ("-");
+  self->num_template_infos = 1;
+  int count = 0;
+  while (ZRYTHM->templates[count])
+    {
+      self->template_infos[
+        self->num_template_infos].name =
+        g_path_get_basename (
+          ZRYTHM->templates[count]);
+      self->template_infos[
+        self->num_template_infos].filename =
+        g_build_filename (
+          ZRYTHM->templates[count],
+          PROJECT_FILE,
+          NULL);
+      self->template_infos[
+        self->num_template_infos].modified =
+          io_file_get_last_modified_datetime (
+            self->template_infos[
+              self->num_template_infos].filename);
+      self->num_template_infos++;
+      count++;
+    }
+
   /* set model to tree view */
   refresh_projects (self);
+
+  /* select first project */
+  GtkTreeSelection *selection =
+    gtk_tree_view_get_selection (
+      GTK_TREE_VIEW (self->projects));
+  GtkTreeIter iter;
+  gtk_tree_model_get_iter_first (
+    self->project_model,
+    &iter);
+  gtk_tree_selection_select_iter (
+    selection, &iter);
+
+  refresh_templates (self);
   gtk_tree_view_set_search_column (
     GTK_TREE_VIEW (self->projects),
     COLUMN_NAME);
+  gtk_tree_view_set_search_column (
+    GTK_TREE_VIEW (self->templates),
+    COLUMN_NAME);
 
   /* add columns to the tree view */
   add_columns (GTK_TREE_VIEW (self->projects));
+  add_columns (GTK_TREE_VIEW (self->templates));
+
+  /* select the first template */
+  self->template_selection =
+    &self->template_infos[0];
 
   gtk_window_set_position (
     GTK_WINDOW (self), GTK_WIN_POS_CENTER_ALWAYS);
@@ -305,32 +452,31 @@ project_assistant_widget_class_init (
   resources_set_class_template (
     klass, "project_assistant.ui");
 
-  gtk_widget_class_bind_template_child (
-    klass,
-    ProjectAssistantWidget,
-    projects);
-  gtk_widget_class_bind_template_child (
-    klass,
-    ProjectAssistantWidget,
-    projects_selection);
-  gtk_widget_class_bind_template_child (
-    klass,
-    ProjectAssistantWidget,
-    remove_btn);
-  gtk_widget_class_bind_template_child (
-    klass,
-    ProjectAssistantWidget,
-    create_new_project);
-  /*gtk_widget_class_bind_template_child (*/
-    /*klass,*/
-    /*ProjectAssistantWidget,*/
-    /*label);*/
-  gtk_widget_class_bind_template_callback (
-    klass,
-    on_create_new_project_toggled);
-  gtk_widget_class_bind_template_callback (
-    klass,
-    on_projects_selection_changed);
+#define BIND_CHILD(x) \
+  gtk_widget_class_bind_template_child ( \
+    klass, \
+    ProjectAssistantWidget, \
+    x)
+
+  BIND_CHILD (projects);
+  BIND_CHILD (projects_selection);
+  BIND_CHILD (templates);
+  BIND_CHILD (templates_selection);
+  BIND_CHILD (templates_box);
+  BIND_CHILD (remove_btn);
+  BIND_CHILD (create_new_project);
+
+#define BIND_CALLBACK(x) \
+  gtk_widget_class_bind_template_callback ( \
+    klass, \
+    x)
+
+  BIND_CALLBACK (on_create_new_project_toggled);
+  BIND_CALLBACK (on_projects_selection_changed);
+  BIND_CALLBACK (on_templates_selection_changed);
+
+#undef BIND_CHILD
+#undef BIND_CALLBACK
 }
 
 static void
