@@ -134,16 +134,12 @@ on_motion (
         GTK_WIDGET (self),
         GTK_STATE_FLAG_PRELIGHT,
         0);
-      bot_bar_change_status (
-        "Scale - Click and drag to move around ("
-        "hold Shift to disable snapping)");
     }
   else if (event->type == GDK_LEAVE_NOTIFY)
     {
       gtk_widget_unset_state_flags (
         GTK_WIDGET (self),
         GTK_STATE_FLAG_PRELIGHT);
-      bot_bar_change_status ("");
     }
 
   return FALSE;
