@@ -26,6 +26,9 @@
 
 #include "config.h"
 
+#include <time.h>
+#include <sys/stat.h>
+
 #include "zrythm.h"
 #include "project.h"
 #include "audio/automation_curve.h"
@@ -53,6 +56,7 @@
 #include "utils/flags.h"
 #include "utils/io.h"
 #include "utils/smf.h"
+#include "utils/string.h"
 #include "utils/ui.h"
 
 #include <gtk/gtk.h>
@@ -79,48 +83,186 @@ tear_down (Project * self)
   free (self);
 }
 
-static void
-update_paths (const char * dir)
-{
-  if (PROJECT->dir)
-    g_free (PROJECT->dir);
-  if (PROJECT->project_file_path)
-    g_free (PROJECT->project_file_path);
-  if (PROJECT->states_dir)
-    g_free (PROJECT->states_dir);
-  if (PROJECT->exports_dir)
-    g_free (PROJECT->exports_dir);
-  if (PROJECT->audio_dir)
-    g_free (PROJECT->audio_dir);
+/**
+ * Frees the current x if any and sets a copy of
+ * the given string.
+ */
+#define DEFINE_SET_STR(x) \
+static void \
+set_##x ( \
+  Project *    self, \
+  const char * x) \
+{ \
+  if (self->x) \
+    g_free (self->x); \
+  self->x = \
+    g_strdup (x); \
+}
 
-  PROJECT->dir = g_strdup (dir);
-  PROJECT->project_file_path =
-    g_build_filename (PROJECT->dir,
-                      PROJECT_FILE,
-                      NULL);
-  g_message ("project file path %s",
-             PROJECT->project_file_path);
-  PROJECT->regions_file_path =
-    g_build_filename (PROJECT->dir,
-                      PROJECT_REGIONS_FILE,
-                      NULL);
-  PROJECT->regions_dir =
-    g_build_filename (PROJECT->dir,
-                      PROJECT_REGIONS_DIR,
-                      NULL);
-  PROJECT->states_dir =
-    g_build_filename (PROJECT->dir,
-                      PROJECT_STATES_DIR,
-                      NULL);
-  PROJECT->exports_dir =
-    g_build_filename (PROJECT->dir,
-                      PROJECT_EXPORTS_DIR,
-                      NULL);
-  PROJECT->audio_dir =
-    g_build_filename (PROJECT->dir,
-                      PROJECT_AUDIO_DIR,
-                      NULL);
-  g_message ("updated paths %s", PROJECT->dir);
+DEFINE_SET_STR (dir);
+DEFINE_SET_STR (title);
+
+#undef DEFINE_SET_STR
+
+/**
+ * Returns the filepath of a backup (directory),
+ * if any,
+ * if it has a newer timestamp than the actual
+ * file being loaded.
+ *
+ * @param dir The non-backup dir.
+ */
+static char *
+get_newer_backup (
+  Project * self)
+{
+  GDir *dir;
+  GError *error;
+  const gchar *filename;
+  struct stat stat_res;
+  struct tm *orig_tm, *nowtm;
+  time_t t1;
+  time_t t2;
+
+  char * filepath =
+    project_get_project_file_path (self, 0);
+  if (stat (filepath, &stat_res)==0)
+    {
+      orig_tm = localtime (&stat_res.st_mtime);
+      t1 = mktime (orig_tm);
+    }
+  else
+    {
+      g_warning (
+        "Failed to get last modified for %s",
+        filepath);
+      return NULL;
+    }
+  g_free (filepath);
+
+  char * result = NULL;
+  char * backups_dir =
+    project_get_backups_dir (self);
+  dir = g_dir_open (backups_dir, 0, &error);
+  while ((filename = g_dir_read_name(dir)))
+    {
+      char * full_path =
+        g_build_filename (
+          backups_dir,
+          filename,
+          PROJECT_FILE,
+          NULL);
+      g_message ("%s", full_path);
+
+      if (stat (full_path, &stat_res)==0)
+        {
+          nowtm = localtime (&stat_res.st_mtime);
+          t2 = mktime (nowtm);
+          /* if backup is after original project */
+          if (difftime (t2, t1) > 0)
+            {
+              if (!result)
+                g_free (result);
+              result =
+                g_build_filename (
+                  backups_dir,
+                  filename,
+                  NULL);
+              t1 = t2;
+            }
+        }
+      else
+        {
+          g_warning (
+            "Failed to get last modified for %s",
+            full_path);
+          return NULL;
+        }
+      g_free (full_path);
+    }
+  g_free (backups_dir);
+
+  return result;
+}
+
+static void
+set_datetime_str (
+  Project * self)
+{
+  if (self->datetime_str)
+    g_free (self->datetime_str);
+  self->datetime_str =
+    datetime_get_current_as_string ();
+}
+
+/**
+ * Sets the next available backup dir to use for
+ * saving a backup during this call.
+ */
+static void
+set_and_create_next_available_backup_dir (
+  Project * self)
+{
+  if (self->backup_dir)
+    g_free (self->backup_dir);
+
+  char * backups_dir =
+    project_get_backups_dir (self);
+
+  int i = 0;
+  do
+    {
+      if (i > 0)
+        {
+          g_free (self->backup_dir);
+          char * bak_title =
+            g_strdup_printf (
+              "%s.bak%d",
+              self->title, i);
+          self->backup_dir =
+            g_build_filename (
+              backups_dir,
+              bak_title, NULL);
+          g_free (bak_title);
+        }
+      else
+        {
+          char * bak_title =
+            g_strdup_printf (
+              "%s.bak",
+              self->title);
+          self->backup_dir =
+            g_build_filename (
+              backups_dir,
+              bak_title, NULL);
+          g_free (bak_title);
+        }
+      i++;
+    } while (
+      io_file_exists (
+        self->backup_dir));
+  g_free (backups_dir);
+
+  io_mkdir (self->backup_dir);
+}
+
+/**
+ * Sets the next available "Untitled Project" title
+ * and directory.
+ *
+ * @param _dir The directory of the project to
+ *   create, including its title.
+ */
+static void
+create_and_set_dir_and_title (
+  Project *    self,
+  const char * _dir)
+{
+  set_dir (self, _dir);
+  char * str =
+    g_path_get_basename (_dir);
+  set_title (self, str);
+  g_free (str);
 }
 
 /**
@@ -138,7 +280,9 @@ create_default (Project * self)
   engine_init (&self->audio_engine, 0);
   undo_manager_init (&self->undo_manager);
 
-  self->title = g_strdup (DEFAULT_PROJECT_NAME);
+  self->title =
+    g_path_get_basename (
+      ZRYTHM->create_project_path);
 
   /* init pinned tracks */
   Track * track =
@@ -168,30 +312,8 @@ create_default (Project * self)
   self->last_selection = SELECTION_TYPE_TRACK;
 
   /* create untitled project */
-  char * untitled_project = _("Untitled Project");
-  char * dir =
-    g_strdup_printf ("%s%s%s",
-                     ZRYTHM->projects_dir,
-                     G_DIR_SEPARATOR_S,
-                     untitled_project);
-  update_paths (dir);
-  int i = 1;
-  while (io_file_exists (dir) &&
-         PROJECT->project_file_path &&
-         io_file_exists (PROJECT->project_file_path))
-    {
-      g_free (dir);
-      dir =
-        g_strdup_printf ("%s%s%s (%d)",
-                         ZRYTHM->projects_dir,
-                         G_DIR_SEPARATOR_S,
-                         untitled_project,
-                         i++);
-      update_paths (dir);
-    }
-  io_mkdir (dir);
-  char * filepath_noext = g_path_get_basename (dir);
-  PROJECT->title = filepath_noext;
+  create_and_set_dir_and_title (
+    self, ZRYTHM->create_project_path);
 
   self->loaded = 1;
 
@@ -222,18 +344,79 @@ create_default (Project * self)
     PROJECT->title);
 }
 
+/**
+ * @param filename The filename to open. This will
+ *   be the template in the case of template, or
+ *   the actual project otherwise.
+ * @param is_template Load the project as a
+ *   template and create a new project from it.
+ */
 static int
-load (char * filename)
+load (
+  const char * filename,
+  const int is_template)
 {
   g_warn_if_fail (filename);
   char * dir = io_get_dir (filename);
-  update_paths (dir);
+
+  set_dir (PROJECT, dir);
+
+  /* if loading an actual project, check for
+   * backups */
+  if (!is_template)
+    {
+      if (PROJECT->backup_dir)
+        g_free (PROJECT->backup_dir);
+      PROJECT->backup_dir =
+        get_newer_backup (PROJECT);
+      if (PROJECT->backup_dir)
+        {
+          g_message (
+            "newer backup found %s",
+            PROJECT->backup_dir);
+
+          GtkWidget * dialog =
+            gtk_message_dialog_new (
+              GTK_WINDOW (MAIN_WINDOW),
+              GTK_DIALOG_MODAL |
+                GTK_DIALOG_DESTROY_WITH_PARENT,
+              GTK_MESSAGE_INFO,
+              GTK_BUTTONS_YES_NO,
+              _("Newer backup found:\n  %s.\n"
+                "Use the newer backup?"),
+              PROJECT->backup_dir);
+          gtk_widget_set_visible (
+            GTK_WIDGET (MAIN_WINDOW), 0);
+          int res =
+            gtk_dialog_run (GTK_DIALOG (dialog));
+          switch (res)
+            {
+            case GTK_RESPONSE_YES:
+              break;
+            case GTK_RESPONSE_NO:
+              g_free (PROJECT->backup_dir);
+              PROJECT->backup_dir = NULL;
+              break;
+            default:
+              break;
+            }
+          gtk_widget_destroy (dialog);
+          gtk_widget_set_visible (
+            GTK_WIDGET (MAIN_WINDOW), 1);
+        }
+    }
 
   gchar * yaml;
   GError *err = NULL;
 
+  char * project_file_path =
+    project_get_project_file_path (
+      PROJECT, PROJECT->backup_dir != NULL);
+  g_message (
+    "loading project file %s",
+    project_file_path);
   g_file_get_contents (
-    PROJECT->project_file_path,
+    project_file_path,
     &yaml,
     NULL,
     &err);
@@ -251,6 +434,7 @@ load (char * filename)
       g_error_free (err);
       RETURN_ERROR
     }
+  g_free (project_file_path);
 
   Project * prj = project_deserialize (yaml);
 
@@ -264,6 +448,13 @@ load (char * filename)
     }
   g_message ("Project successfully deserialized.");
 
+  if (is_template)
+    {
+      g_free (dir);
+      dir =
+        g_strdup (ZRYTHM->create_project_path);
+    }
+
   int loading_while_running = PROJECT->loaded;
   if (loading_while_running)
     {
@@ -283,20 +474,12 @@ load (char * filename)
 
   g_message ("initing loaded structures");
   PROJECT = prj;
-  update_paths (dir);
+
+  /* re-update paths for the newly loaded project */
+  set_dir (prj, dir);
+
   undo_manager_init (&PROJECT->undo_manager);
-  /*init_loaded_ports ();*/
   engine_init (AUDIO_ENGINE, 1);
-  /*init_loaded_regions ();*/
-  /*init_loaded_plugins ();*/
-  /*init_loaded_tracks ();*/
-  /*init_loaded_midi_notes ();*/
-  /*init_loaded_automation_points ();*/
-  /*init_loaded_automation_curves ();*/
-  /*init_loaded_chords ();*/
-  /*init_loaded_automatables ();*/
-  /*init_loaded_automation_tracks ();*/
-  /*init_loaded_automation_lanes ();*/
 
   char * filepath_noext = g_path_get_basename (dir);
   PROJECT->title = filepath_noext;
@@ -383,13 +566,21 @@ load (char * filename)
  * If project has a filename set, it loads that.
  * Otherwise it loads the default project.
  *
- * Returns 0 if successful, non-zero otherwise.
+ * @param filename The filename to open. This will
+ *   be the template in the case of template, or
+ *   the actual project otherwise.
+ * @param is_template Load the project as a
+ *   template and create a new project from it.
+ *
+ * @return 0 if successful, non-zero otherwise.
  */
 int
-project_load (char * filename)
+project_load (
+  char *    filename,
+  const int is_template)
 {
   if (filename)
-    load (filename);
+    load (filename, is_template);
   else
     create_default (PROJECT);
 
@@ -415,6 +606,24 @@ project_load (char * filename)
   return 0;
 }
 
+/**
+ * Autosave callback.
+ */
+int
+project_autosave_cb (
+  void * data)
+{
+  if (PROJECT && PROJECT->loaded &&
+      PROJECT->dir &&
+      PROJECT->datetime_str)
+    {
+      project_save (
+        PROJECT, PROJECT->dir, 1);
+    }
+
+  return G_SOURCE_CONTINUE;
+}
+
 /**
  * Sets if the project has range and updates UI.
  */
@@ -426,30 +635,146 @@ project_set_has_range (int has_range)
   EVENTS_PUSH (ET_RANGE_SELECTION_CHANGED, NULL);
 }
 
+/**
+ * Returns the backups dir for the given Project.
+ */
+char *
+project_get_backups_dir (
+  Project * self)
+{
+  g_warn_if_fail (self->dir);
+  return
+    g_build_filename (
+      self->dir,
+      PROJECT_BACKUPS_DIR,
+      NULL);
+}
+
+/**
+ * Returns the exports dir for the given Project.
+ */
+char *
+project_get_exports_dir (
+  Project * self)
+{
+  g_warn_if_fail (self->dir);
+  return
+    g_build_filename (
+      self->dir,
+      PROJECT_EXPORTS_DIR,
+      NULL);
+}
+
+/**
+ * Returns the states dir for the given Project.
+ *
+ * @param is_backup 1 to get the states dir of the
+ *   current backup instead of the main project.
+ */
+char *
+project_get_states_dir (
+  Project * self,
+  const int is_backup)
+{
+  g_warn_if_fail (self->dir);
+  if (is_backup)
+    return
+      g_build_filename (
+        self->backup_dir,
+        PROJECT_STATES_DIR,
+        NULL);
+  else
+    return
+      g_build_filename (
+        self->dir,
+        PROJECT_STATES_DIR,
+        NULL);
+}
+
+/**
+ * Returns the audio dir for the given Project.
+ */
+char *
+project_get_audio_dir (
+  Project * self)
+{
+  g_warn_if_fail (self->dir);
+  return
+    g_build_filename (
+      self->dir,
+      PROJECT_AUDIO_DIR,
+      NULL);
+}
+
+/**
+ * Returns the full project file (project.yml)
+ * path.
+ *
+ * @param is_backup 1 to get the states dir of the
+ *   current backup instead of the main project.
+ */
+char *
+project_get_project_file_path (
+  Project * self,
+  const int is_backup)
+{
+  g_warn_if_fail (self->dir);
+  if (is_backup)
+    return
+      g_build_filename (
+        self->backup_dir,
+        PROJECT_FILE,
+        NULL);
+  else
+    return
+      g_build_filename (
+        self->dir,
+        PROJECT_FILE,
+        NULL);
+}
+
+/**
+ * Saves the project to a project file in the
+ * given dir.
+ *
+ * @param is_backup 1 if this is a backup. Backups
+ *   will be saved as <original filename>.bak<num>.
+ */
 int
 project_save (
-  Project * self,
-  const char * dir)
+  Project *    self,
+  const char * _dir,
+  int          is_backup)
 {
   int i, j;
 
-  io_mkdir (dir);
-  update_paths (dir);
-  PROJECT->title = io_path_get_basename (dir);
+  char * dir = g_strdup (_dir);
+
+  /* set the dir and create it if it doesn't
+   * exist */
+  set_dir (self, dir);
+  io_mkdir (PROJECT->dir);
+
+  /* set the title */
+  char * basename =
+    io_path_get_basename (dir);
+  set_title (self, basename);
+  g_free (basename);
 
   /* save current datetime */
-  if (self->datetime_str)
-    g_free (self->datetime_str);
-  PROJECT->datetime_str =
-    datetime_get_current_as_string ();
+  set_datetime_str (self);
 
-  /*smf_save_regions ();*/
+  /* if backup, get next available backup dir */
+  if (is_backup)
+    set_and_create_next_available_backup_dir (self);
 
   /* write plugin states, prepare channels for
    * serialization, */
   Track * track;
   Channel * ch;
   Plugin * pl;
+  char * states_dir =
+    project_get_states_dir (self, is_backup);
   for (i = 0; i < TRACKLIST->num_tracks; i++)
     {
       track = TRACKLIST->tracks[i];
@@ -478,7 +803,7 @@ project_save (
                   j);
               char * state_dir_plugin =
                 g_build_filename (
-                  PROJECT->states_dir,
+                  states_dir,
                   tmp,
                   NULL);
               g_free (tmp);
@@ -493,11 +818,15 @@ project_save (
             }
         }
     }
+  g_free (states_dir);
 
+  char * project_file_path =
+    project_get_project_file_path (
+      self, is_backup);
   char * yaml = project_serialize (PROJECT);
   GError *err = NULL;
   g_file_set_contents (
-    PROJECT->project_file_path,
+    project_file_path,
     yaml,
     -1,
     &err);
@@ -510,17 +839,24 @@ project_save (
       RETURN_ERROR;
     }
 
-  zrythm_add_to_recent_projects (
-    ZRYTHM,
-    PROJECT->project_file_path);
-  PROJECT->title = g_path_get_basename (dir);
-
-  ui_show_notification (_("Project saved."));
+  if (is_backup)
+    {
+      ui_show_notification (_("Backup saved."));
+    }
+  else
+    {
+      zrythm_add_to_recent_projects (
+        ZRYTHM, project_file_path);
+      ui_show_notification (_("Project saved."));
+    }
+  g_free (project_file_path);
 
   header_notebook_widget_set_subtitle (
     MW_HEADER_NOTEBOOK,
     PROJECT->title);
 
+  g_free (dir);
+
   RETURN_OK;
 }
 
