@@ -29,6 +29,7 @@
 #include "gui/accel.h"
 #include "gui/backend/file_manager.h"
 #include "gui/backend/piano_roll.h"
+#include "gui/widgets/create_project_dialog.h"
 #include "gui/widgets/first_run_assistant.h"
 #include "gui/widgets/main_window.h"
 #include "gui/widgets/project_assistant.h"
@@ -185,13 +186,25 @@ init_recent_projects ()
     (const char * const *) ZRYTHM->recent_projects);
 }
 
+/**
+ * Initializes the array of recent projects in
+ * Zrythm app.
+ */
+static void
+init_templates ()
+{
+
+  ZRYTHM->templates =
+    io_get_files_in_dir (ZRYTHM->templates_dir);
+}
+
 /**
  * FIXME move somewhere else.
  */
 void
 zrythm_add_to_recent_projects (
   Zrythm * self,
-  const char * filepath)
+  const char * _filepath)
 {
   /* if we are at max
    * projects */
@@ -208,11 +221,14 @@ zrythm_add_to_recent_projects (
           ZRYTHM->num_recent_projects - 1]);
     }
 
+  char * filepath =
+    g_strdup (_filepath);
+
   array_insert (
     ZRYTHM->recent_projects,
     ZRYTHM->num_recent_projects,
     0,
-    (char *) filepath);
+    filepath);
 
   /* set last element to NULL because the call
    * takes a NULL terminated array */
@@ -352,13 +368,26 @@ static void on_setup_main_window (GSimpleAction  *action,
   mixer_recalc_graph (MIXER);
   g_atomic_int_set (&AUDIO_ENGINE->run, 1);
 
+  /* add timeout for auto-saving projects */
+  int autosave_interval =
+    g_settings_get_int (
+      S_PREFERENCES, "autosave-interval") * 60;
+  if (autosave_interval > 0)
+    {
+      g_timeout_add_seconds (
+        autosave_interval,
+        project_autosave_cb,
+        NULL);
+    }
+
   free (data);
 }
 
 /**
  * Called after the main window has been initialized.
  *
- * Loads the project backend or creates the default one.
+ * Loads the project backend or creates the default
+ * one.
  * FIXME rename
  */
 static void on_load_project (GSimpleAction  *action,
@@ -367,7 +396,9 @@ static void on_load_project (GSimpleAction  *action,
 {
   g_message ("load_project");
 
-  project_load (ZRYTHM->open_filename);
+  project_load (
+    ZRYTHM->open_filename,
+    ZRYTHM->opening_template);
 
   g_action_group_activate_action (
     G_ACTION_GROUP (zrythm_app),
@@ -403,28 +434,81 @@ static void
 on_finish (GtkAssistant * _assistant,
           gpointer       user_data)
 {
+  zrythm->creating_project = 1;
   if (user_data) /* if cancel */
     {
       gtk_widget_destroy (GTK_WIDGET (assistant));
       zrythm->open_filename = NULL;
     }
-  else if (!assistant->selection) /* if apply to create new project */
+  /* if we are loading a template and template
+   * exists */
+  else if (assistant->load_template &&
+           assistant->template_selection &&
+           assistant->template_selection->
+             filename[0] != '-')
+    {
+      zrythm->open_filename =
+        assistant->template_selection->filename;
+      g_message (
+        "Creating project from template: %s",
+        zrythm->open_filename);
+      zrythm->opening_template = 1;
+    }
+  /* if we are loading a project */
+  else if (!assistant->load_template &&
+           assistant->project_selection)
+    {
+      zrythm->open_filename =
+        assistant->project_selection->filename;
+      g_message (
+        "Loading project: %s",
+        zrythm->open_filename);
+      zrythm->creating_project = 0;
+    }
+  /* no selection, load blank project */
+  else
     {
       zrythm->open_filename = NULL;
+      g_message (
+        "Creating blank project");
     }
-  else /* if apply to load project */
+
+  /* if not loading a project, show dialog to
+   * select directory and name */
+  int quit = 0;
+  if (zrythm->creating_project)
     {
-      zrythm->open_filename = assistant->selection->filename;
+      CreateProjectDialogWidget * dialog =
+        create_project_dialog_widget_new ();
+
+      int ret =
+        gtk_dialog_run (GTK_DIALOG (dialog));
+      if (ret != GTK_RESPONSE_OK)
+        quit = 1;
+      gtk_widget_destroy (GTK_WIDGET (dialog));
+
+      g_message ("creating project %s",
+                 zrythm->create_project_path);
+    }
+
+  if (quit)
+    {
+      g_application_quit (
+        G_APPLICATION (zrythm_app));
+    }
+  else
+    {
+      gtk_widget_set_visible (
+        GTK_WIDGET (assistant), 0);
+      data->message =
+        "Finishing";
+      data->progress = 1.0;
+      update_splash (data);
+      g_action_group_activate_action (
+        G_ACTION_GROUP (zrythm_app),
+        "init_main_window",
+        NULL);
     }
-  gtk_widget_set_visible (GTK_WIDGET (assistant), 0);
-  data->message =
-    "Finishing";
-  data->progress = 1.0;
-  update_splash (data);
-  g_action_group_activate_action (
-    G_ACTION_GROUP (zrythm_app),
-    "init_main_window",
-    NULL);
 }
 
 static void
@@ -501,6 +585,7 @@ static void on_prompt_for_project (GSimpleAction  *action,
       /* init zrythm folders ~/Zrythm */
       init_dirs_and_files ();
       init_recent_projects ();
+      init_templates ();
 
       /* init log */
       g_message ("Initing log...");
